---
title: "LC-MS/MS data analysis with xcms"
package: xcms
output:
  BiocStyle::html_document:
    toc_float: true
vignette: >
  %\VignetteIndexEntry{LC-MS/MS data analysis with xcms}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
  %\VignetteDepends{xcms,msdata,BiocStyle}
  %\VignettePackage{xcms}
  %\VignetteKeywords{mass spectrometry, metabolomics}
bibliography: references.bib
csl: biomed-central.csl
references:
- id: dummy
  title: no title
  author:
  - family: noname
    given: noname
---

```{r biocstyle, echo = FALSE, results = "asis"}
BiocStyle::markdown()
```

**Package**: `r Biocpkg("xcms")`<br />
**Authors**: Johannes Rainer, Michael Witting<br />
**Modified**: `r file.info("xcms-lcms-ms.Rmd")$mtime`<br />
**Compiled**: `r date()`

```{r init, message = FALSE, echo = FALSE, results = "hide" }
## Silently loading all packages
library(BiocStyle)
library(xcms)
library(pander)
register(SerialParam())

```

# Introduction

Metabolite identification is an important step in non-targeted metabolomics and
requires different steps. One involves the use of tandem mass spectrometry to
generate fragmentation spectra of detected metabolites (LC-MS/MS), which are
then compared to fragmentation spectra of known metabolites. Different
approaches exist for the generation of these fragmentation spectra, whereas the
most used is data dependent acquisition (DDA) also known as the top-n method. In
this method the top N most intense m/z values from a MS1 scan are selected for
fragmentation in the next N scans before the cycle starts again. This method
allows to generate clean MS2 fragmentation spectra on the fly during acquisition
without the need for further experiments, but suffers from poor coverage of the
detected metabolites (since only a limited number of ions are fragmented).

Data independent approaches (DIA) like Bruker bbCID, Agilent AllIons or Waters
MSe don't use such a preselection, but rather fragment all detected molecules at
once. They are using alternating schemes with scan of low and high collision
energy to collect MS1 and MS2 data. Using this approach, there is no problem in
coverage, but the relation between the precursor and fragment masses is lost
leading to chimeric spectra. Sequential Window Acquisition of all Theoretical
Mass Spectra (or SWATH [@Ludwig:2018hv]) combines both approaches through a
middle-way approach. There is no precursor selection and acquisition is
independent of acquired data, but rather than isolating all precusors at once,
defined windows (i.e. ranges of m/z values) are used and scanned. This reduces
the overlap of fragment spectra while still keeping a high coverage.

This document showcases the analysis of two small LC-MS/MS data sets using `r
Biocpkg("xcms")`. The data files used are reversed-phase LC-MS/MS runs from the
Agilent Pesticide mix obtained from a Sciex 6600 Triple ToF operated in SWATH
acquisition mode. For comparison a DDA file from the same sample is included.

# Analysis of DDA data

Below we load the example DDA data set using the `readMSData` function from the
`r Biocpkg("MSnbase")` package.

```{r load-dda-data, message = FALSE}
library(xcms)

dda_file <- system.file("TripleTOF-SWATH/PestMix1_DDA.mzML",
                        package = "msdata")
dda_data <- readMSData(dda_file, mode = "onDisk")
```

```{r subset-dda, echo = FALSE, message = FALSE, eval = TRUE}
#' Silently sub-setting the object to speed-up analysis
dda_data <- filterRt(dda_data, rt = c(200, 600))
```

The variable `dda_data` contains now all MS1 and MS2 spectra from the specified
mzML file. The number of spectra for each MS level is listed below.

```{r dda-table-mslevel}
table(msLevel(dda_data))
```

Next we perform the chromatographic peak detection on the MS level 1 data with
the `findChromPeaks` method. Below we define the settings for a *centWave*-based
peak detection and perform the analysis.

```{r dda-find-chrom-peaks-ms1, message = FALSE}
cwp <- CentWaveParam(snthresh = 5, noise = 100, ppm = 10,
                     peakwidth = c(3, 30))
dda_data <- findChromPeaks(dda_data, param = cwp)
```

In total `r nrow(chromPeaks(dda_data))` peaks were identified in the present
data set.

The advantage of LC-MS/MS data is that (MS1) ions are fragmented and the
corresponding MS2 spectra measured. Thus, for some of the ions (identified as
MS1 chromatographic peaks) MS2 spectra are available. These can facilitate the
annotation of the respective MS1 chromatographic peaks (or MS1 features after a
correspondence analysis). MS2 spectra for identified chromatographic peaks can
be extracted with the `chromPeakSpectra` method which returns a `Spectra` object
of MS2 spectra associated with a chromatographic peak (i.e. with their retention
time within the retention time window of a chromatographic peak and their
precursor m/z within the m/z range of the same chromatographic peak.

```{r dda-spectra, message = FALSE}
dda_spectra <- chromPeakSpectra(dda_data)
dda_spectra
```

The metadata column `"peak_id"` contains the identifiers of the chromatographic
peaks the MS2 spectrum is associated with.

We next use the MS2 information to aid in the annotation of a chromatographic
peak. As an example we use a chromatographic peak of an ion with an m/z of
304.1131 which we extract in the code block below.

```{r dda-ms2-example, message = FALSE}
ex_mz <- 304.1131
chromPeaks(dda_data, mz = ex_mz, ppm = 20)
```

A search of potential ions with a similar m/z in a reference database
(e.g. [Metlin](https://metlin.scripps.edu)) returned a large list of potential
hits, most with a very small ppm. For two of the hits,
[Flumazenil](https://en.wikipedia.org/wiki/Flumazenil) (Metlin ID 2724) and
[Fenamiphos](https://en.wikipedia.org/wiki/Fenamiphos) (Metlin ID 72445)
experimental MS2 spectra are available. Thus, we could match the MS2 spectrum
for the identified chromatographic peak against these to annotate our ion. Below
we extract all MS2 spectra that were associated with the candidate
chromatographic peak using the ID of the peak in the present data set.

```{r dda-ms2-get-ms2, message = FALSE}
ex_id <- rownames(chromPeaks(dda_data, mz = ex_mz, ppm = 20))
ex_spectra <- dda_spectra[mcols(dda_spectra)$peak_id == ex_id]
ex_spectra
```

There are 5 MS2 spectra representing fragmentation of the ion(s) measured
in our candidate chromatographic peak. We next reduce this to a single MS2
spectrum using the `combineSpectra` method employing the `consensusSpectrum`
function to determine which peaks to keep in the resulting spectrum.

```{r dda-ms2-consensus}
ex_spectrum <- combineSpectra(ex_spectra, method = consensusSpectrum, mzd = 0,
                              ppm = 20, minProp = 0.8, weighted = FALSE,
                              intensityFun = median, mzFun = median)
ex_spectrum
```

Mass peaks from all input spectra with a difference in m/z smaller 20 ppm
(parameter `ppm`) were combined into one peak and the median m/z and intensity
is reported for these. Due to parameter `minProp = 0.8`, the resulting MS2
spectrum contains only peaks that were present in 80% of the input spectra.

A plot of this *consensus* spectrum is shown below.

```{r dda-ms2-consensus-plot, message = FALSE, fig.cap = "Consensus MS2 spectrum created from all measured MS2 spectra for ions of chromatographic peak CP53.", fig.width = 8, fig.height = 8}
plot(ex_spectrum[[1]])
```

We could now match the consensus spectrum against a database of MS2 spectra. In
our example we simply load MS2 spectra for the two compounds with matching m/z
exported from Metlin. For each of the compounds MS2 spectra created with
collision energies of 0V, 10V, 20V and 40V are available. Below we import the
respective data and plot our candidate spectrum against the MS2 spectra of
Flumanezil and Fenamiphos (from a collision energy of 20V).

```{r dda-ms2-metlin-match, fig.cap = "Mirror plots for the candidate MS2 spectrum against Flumanezil (left) and Fenamiphos (right). The upper panel represents the candidate MS2 spectrum, the lower the target MS2 spectrum. Matching peaks are indicated with a dot.", fig.width = 12, fig.height = 6}
flumanezil <- spectra(readMgfData(
    system.file("mgf/metlin-2724.mgf", package = "xcms")))
fenamiphos <- spectra(readMgfData(
    system.file("mgf/metlin-72445.mgf", package = "xcms")))

par(mfrow = c(1, 2))
plot(ex_spectrum[[1]], flumanezil[[3]], main = "against Flumanezil",
     tolerance = 40e-6)
plot(ex_spectrum[[1]], fenamiphos[[3]], main = "against Fenamiphos",
     tolerance = 40e-6)
```

Our candidate spectrum matches Fenamiphos, thus, our example chromatographic
peak represents signal measured for this compound. In addition to plotting the
spectra, we can also calculate similarities between them with the
`compareSpectra` method (e.g. using the *dotproduct* method as shown below).

```{r dda-ms2-dotproduct}
compareSpectra(ex_spectrum[[1]], flumanezil[[3]], binSize = 0.02,
               fun = "dotproduct")
compareSpectra(ex_spectrum[[1]], fenamiphos[[3]], binSize = 0.02,
               fun = "dotproduct")
```

Clearly, the candidate spectrum does not match Flumanezil, while it has a high
similarity to Fenamiphos. While we performed here the MS2-based annotation on a
single chromatographic peak, this could be easily extended to the full list of
MS2 spectra (returned by `chromPeakSpectra`) for all chromatographic peaks in an
experiment. Respective code facilitating this will be implemented in future.

In the present example we used only a single data file and we did thus not need
to perform a sample alignment and correspondence analysis. These tasks could
however be performed similarly to *plain* LC-MS data, retention times of
recorded MS2 spectra would however also be adjusted during alignment based on
the MS1 data. After correspondence analysis (peak grouping) MS2 spectra for
*features* can be extracted with the `featureSpectra` function which returns all
MS2 spectra associated with any chromatographic peak of a feature.

Note also that this workflow can be included into the *Feature-Based
Molecular Networking*
[FBMN](https://ccms-ucsd.github.io/GNPSDocumentation/featurebasedmolecularnetworking/)
to match MS2 spectra against [GNPS](https://gnps.ucsd.edu/). See
[here](https://ccms-ucsd.github.io/GNPSDocumentation/featurebasedmolecularnetworking-with-xcms3/)
for more details and examples.


# SWATH data analysis

In this section we analyze a small SWATH data set consisting of a single mzML
file with data from the same sample analyzed in the previous section but
recorded in SWATH mode. We again read the data with the `readMSData`
function. The resulting object will contain all recorded MS1 and MS2
spectra in the specified file.

```{r load-swath-data, message = FALSE}
swath_file <- system.file("TripleTOF-SWATH",
                          "PestMix1_SWATH.mzML",
                          package = "msdata")

swath_data <- readMSData(swath_file, mode = "onDisk")
```

```{r echo = FALSE, message = FALSE, eval = TRUE}
swath_data <- filterRt(swath_data, rt = c(200, 600))
```

Below we determine the number of MS level 1 and 2 spectra in the present data
set.

```{r swath-table-mslevel}
table(msLevel(swath_data))
```

As described in the introduction, in SWATH mode all ions within pre-defined
isolation windows are fragmented and MS2 spectra measured. The definition of
these isolation windows (SWATH pockets) is imported from the mzML files and
stored in the object's `fData` (which provides additional annotations for each
individual spectrum). Below we inspect the respective information for the first
few spectra. The upper and lower isolation window m/z can be extracted with the
`isolationWindowLowerMz` and `isolationWindowUpperMz`.

```{r fdata-isolationwindow}
head(fData(swath_data)[, c("isolationWindowTargetMZ",
                           "isolationWindowLowerOffset",
                           "isolationWindowUpperOffset",
                           "msLevel", "retentionTime")])

head(isolationWindowLowerMz(swath_data))
head(isolationWindowUpperMz(swath_data))
```

In the present data set we use the value of the *isolation window target m/z* to
define the individual SWATH pockets. Below we list the number of spectra that
are recorded in each pocket/isolation window.

```{r}
table(isolationWindowTargetMz(swath_data))
```

We have thus 1,000 MS2 spectra measured in each isolation window.


## Chromatographic peak detection in MS1 and MS2 data

Similar to a *conventional* LC-MS analysis, we perform first a chromatographic
peak detection (on the MS level 1 data) with the `findChromPeaks` method. Below
we define the settings for a *centWave*-based peak detection and perform the
analysis.

```{r find-chrom-peaks-ms1, message = FALSE}
cwp <- CentWaveParam(snthresh = 5, noise = 100, ppm = 10,
                     peakwidth = c(3, 30))
swath_data <- findChromPeaks(swath_data, param = cwp)
```

Next we perform a chromatographic peak detection in the MS level 2 data of each
isolation window. We use the `findChromPeaksIsolationWindow` function employing
the same peak detection algorithm reducing however the required signal-to-noise
ratio. The `isolationWindow` parameter allows to specify which MS2 spectra
belong to which isolation window and hence defines in which set of MS2 spectra
chromatographic peak detection should be performed. While the default value for
this parameter uses isolation windows provided by calling
`isolationWindowTargetMz` on the object, it would also be possible to manually
define the isolation windows, e.g. if the corresponding information is not
available in the input mzML files.

```{r find-chrom-peaks-ms2, message = FALSE}
cwp <- CentWaveParam(snthresh = 3, noise = 10, ppm = 10,
                     peakwidth = c(3, 30))
swath_data <- findChromPeaksIsolationWindow(swath_data, param = cwp)
```

The `findChromPeaksIsolationWindow` function added all peaks identified in the
individual isolation windows to the `chromPeaks` matrix containing already the
MS1 chromatographic peaks. These newly added peaks can be identified by the
value of the `"isolationWindow"` column in the corresponding row in
`chromPeakData`, which lists also the MS level in which the peak was identified.

```{r}
chromPeakData(swath_data)
```

Below we count the number of chromatographic peaks identified within each
isolation window (the number of chromatographic peaks identified in MS1 is
`r sum(chromPeakData(swath_data)$ms_level == 1)`).

```{r}
table(chromPeakData(swath_data)$isolationWindow)
```

We thus successfully identified chromatographic peaks in the different MS levels
and isolation windows, but don't have any actual MS2 *spectra* yet. These have
to be reconstructed from the available chromatographic peak data which we will
done in the next section.


## Reconstruction of MS2 spectra

Identifying the signal of the fragment ions for the precursor measured by each
MS1 chromatographic peak is a non-trivial task. The MS2 spectrum of the fragment
ion for each MS1 chromatographic peak has to be reconstructed from the available
MS2 signal (i.e. the chromatographic peaks identified in MS level 2). For SWATH
data, fragment ion signal should be present in the isolation window that
contains the m/z of the precursor ion and the chromatographic peak shape of the
MS2 chromatographic peaks of fragment ions of a specific precursor should have a
similar retention time and peak shape than the precursor's MS1 chromatographic
peak.

After detection of MS1 and MS2 chromatographic peaks has been performed, we can
reconstruct the MS2 spectra using the `reconstructChromPeakSpectra`
function. This function defines an MS2 spectrum for each MS1 chromatographic
peak based on the following approach:

- Identify MS2 chromatographic peaks in the isolation window containing the m/z
  of the ion (the MS1 chromatographic peak) that have approximately the same
  retention time than the MS1 chromatographic peak (the accepted difference in
  retention time can be defined with the `diffRt` parameter).
- Extract the MS1 chromatographic peak and all MS2 chromatographic peaks
  identified by the previous step and correlate the peak shapes of the candidate
  MS2 chromatographic peaks with the shape of the MS1 peak. MS2 chromatographic
  peaks with a correlation coefficient larger than `minCor` are retained.
- Reconstruct the MS2 spectrum using the m/z of all above selected MS2
  chromatographic peaks and their intensity; each MS2 chromatographic peak
  selected for an MS1 peak will thus represent one **mass peak** in the
  reconstructed spectrum.

To illustrate this process we perform the individual steps on the example of
Fenamiphos (exact mass 303.105800777 and m/z of [M+H]+ adduct 304.113077). As
a first step we extract the chromatographic peak for this ion.

```{r fena-extract-peak}
fenamiphos_mz <- 304.113077
fenamiphos_ms1_peak <- chromPeaks(swath_data, mz = fenamiphos_mz, ppm = 2)
fenamiphos_ms1_peak
```

Next we identify all MS2 chromatographic peaks that were identified in the
isolation window containing the m/z of Fenamiphos. The information on the
isolation window in which a chromatographic peak was identified is available in
the `chromPeakData` (which contains arbitrary additional annotations to each
individual chromatographic peak).

```{r fena-identify-ms2}
keep <- chromPeakData(swath_data)$isolationWindowLowerMz < fenamiphos_mz &
        chromPeakData(swath_data)$isolationWindowUpperMz > fenamiphos_mz
```

We also require the retention time of the MS2 chromatographic peaks to be
similar to the retention time of the MS1 peak and extract the corresponding peak
information.

```{r fena-check-rt}
keep <- keep &
    chromPeaks(swath_data)[, "rtmin"] < fenamiphos_ms1_peak[, "rt"] &
    chromPeaks(swath_data)[, "rtmax"] > fenamiphos_ms1_peak[, "rt"]

fenamiphos_ms2_peak <- chromPeaks(swath_data)[which(keep), ]
```

In total `r sum(keep, na.rm = TRUE)` MS2 chromatographic peaks match all the
above condition. Next we extract their corresponding ion chromatograms, as well
as the ion chromatogram of the MS1 peak. Note that we extend the retention time
range by 1 seconds on both sides. In addition we have to filter the object
first by isolation window, keeping only spectra that were measured in that
specific window and to specify to extract the chromatographic data from MS2
spectra (with `msLevel = 2L`).

```{r fena-eic-extract, warning = FALSE}
rtr <- fenamiphos_ms1_peak[, c("rtmin", "rtmax")]
rtr[1] <- rtr[1] - 1
rtr[2] <- rtr[2] + 1
mzr <- fenamiphos_ms1_peak[, c("mzmin", "mzmax")]
fenamiphos_ms1_chr <- chromatogram(swath_data, rt = rtr, mz = mzr)

rtr <- fenamiphos_ms2_peak[, c("rtmin", "rtmax")]
rtr[, 1] <- rtr[, 1] - 1
rtr[, 2] <- rtr[, 2] + 1
mzr <- fenamiphos_ms2_peak[, c("mzmin", "mzmax")]
fenamiphos_ms2_chr <- chromatogram(
    filterIsolationWindow(swath_data, mz = fenamiphos_mz),
    rt = rtr, mz = mzr, msLevel = 2L)
```

We can now plot the extracted ion chromatogram of the MS1 and the extracted MS2
data.

```{r fena-eic-plot, fig.width = 10, fig.height = 5, fig.cap = "Extracted ion chromatograms for Fenamiphos from MS1 (blue) and potentially related signal in MS2 (grey)."}
plot(rtime(fenamiphos_ms1_chr[1, 1]),
     intensity(fenamiphos_ms1_chr[1, 1]),
     xlab = "retention time [s]", ylab = "intensity", pch = 16,
     ylim = c(0, 5000), col = "blue", type = "b", lwd = 2)
#' Add data from all MS2 peaks
tmp <- lapply(fenamiphos_ms2_chr@.Data,
              function(z) points(rtime(z), intensity(z),
                                 col = "#00000080",
                                 type = "b", pch = 16))
```

Next we can calculate correlations between the peak shapes of each MS2
chromatogram with the MS1 peak. We perform the correlation below for one of the
MS2 chromatographic peaks. Note that, because spectra are recorded
consecutively, the retention times of the individual data points will differ for
the MS2 and MS1 chromatographic data and data points have thus to be matched
(aligned) before performing the correlation analysis. This is done automatically
by the `correlate` function. See the help for the `align` method for more
information on alignment options.

```{r fena-cor}
correlate(fenamiphos_ms2_chr[1, 1],
          fenamiphos_ms1_chr[1, 1], align = "approx")
```

After identifying the MS2 chromatographic peaks with shapes of enough high
similarity to the MS1 chromatographic peaks, an MS2 spectrum could be
*reconstructed* based on the m/z and intensities of the MS2 chromatographic
peaks.

The `reconstructChromPeakSpectra` function performs the above analysis for each
individual MS1 chromatographic peak in a SWATH data set. Below we reconstruct
MS2 spectra for our example data requiring a peak shape correlation higher than
`0.9` between the candidate MS2 chromatographic peak and the target MS1
chromatographic peak.

```{r reconstruct-ms2, message = FALSE}
swath_spectra <- reconstructChromPeakSpectra(swath_data, minCor = 0.9)
swath_spectra
```

As a result we got a `Spectra` object of length equal to the number of MS1 peaks
in our data. A `peaksCount` of `0` indicates that no MS2 spectrum could be
defined based on the used settings. For reconstructed spectra additional
annotations are available such as the IDs of the MS2 chromatographic peaks from
which the spectrum was reconstructed (`"ms2_peak_id"`) as well as the
correlation coefficient of their chromatographic peak shape with the precursor's
shape (`"ms2_peak_cor"`). Metadata column `"peak_id"` contains the ID of the MS1
chromatographic peak.

We next extract the MS2 spectrum for our example peak most likely representing
[M+H]+ ions of Fenamiphos using its chromatographic peak ID:

```{r fena-swath-peak}
fenamiphos_swath_spectrum <- swath_spectra[
    mcols(swath_spectra)$peak_id == rownames(fenamiphos_ms1_peak)]
```

We can now compare the reconstructed spectrum to the example consensus spectrum
from the DDA experiment in the previous section (variable `ex_spectrum`) as well
as to the MS2 spectrum for Fenamiphos from Metlin (with a collision energy of
10V).

```{r fena-swath-plot, fig.cap = "Mirror plot comparing the reconstructed MS2 spectrum for Fenamiphos (upper panel) against the measured spectrum from the DDA data and the Fenamiphhos spectrum from Metlin.", fig.width = 12, fig.height = 6}
par(mfrow = c(1, 2))
plot(fenamiphos_swath_spectrum[[1]], ex_spectrum[[1]],
     tolerance = 50e-6, main = "against DDA")
plot(fenamiphos_swath_spectrum[[1]], fenamiphos[[2]],
     tolerance = 50e-6, main = "against Metlin")
```

As a second example we analyze the signal from an [M+H]+ ion with an m/z of
376.0381 (which would match
[Prochloraz](https://en.wikipedia.org/wiki/Prochloraz)). We first identify the
MS1 chromatographic peak for that m/z and retrieve the reconstructed MS2
spectrum for that peak.

```{r pro-swath}
prochloraz_mz <- 376.0381

prochloraz_ms1_peak <- chromPeaks(swath_data, msLevel = 1L,
                                  mz = prochloraz_mz, ppm = 5)
prochloraz_ms1_peak

prochloraz_swath_spectrum <- swath_spectra[
    mcols(swath_spectra)$peak_id == rownames(prochloraz_ms1_peak)]
```

In addition we identify the corresponding MS1 peak in the DDA data set, extract
all measured MS2 chromatographic peaks and build the consensus spectrum from
these.

```{r pro-dda}
prochloraz_dda_peak <- chromPeaks(dda_data, msLevel = 1L,
                                  mz = prochloraz_mz, ppm = 5)
prochloraz_dda_peak
```

The retention times for the chromatographic peaks from the DDA and SWATH data
match almost perfectly. Next we get the MS2 spectra for this peak.

```{r pro-dda-ms2}
prochloraz_dda_spectra <- dda_spectra[
    mcols(dda_spectra)$peak_id == rownames(prochloraz_dda_peak)]
prochloraz_dda_spectra
```

In total 5 spectra were measured, some with a relatively high number of
peaks. Next we combine them into a consensus spectrum.

```{r pro-dda-consensus}
prochloraz_dda_spectrum <- combineSpectra(
    prochloraz_dda_spectra, method = consensusSpectrum, msd = 0, ppm = 20,
    minProp = 0.8, weighted = FALSE, intensityFun = median, mzFun = median)
```

At last we load also the Prochloraz MS2 spectra (for different collision
energies) from Metlin.

```{r prochloraz-metlin}
prochloraz <- spectra(readMgfData(
    system.file("mgf/metlin-68898.mgf", package = "xcms")))
```

To validate the reconstructed spectrum we plot it against the corresponding DDA
spectrum and the MS2 spectrum for Prochloraz (for a collision energy of 10V)
from Metlin.

```{r pro-swath-plot, fig.cap = "Mirror plot comparing the reconstructed MS2 spectrum for Prochloraz (upper panel) against the measured spectrum from the DDA data and the Prochloraz spectrum from Metlin.", fig.width = 12, fig.height = 6}
par(mfrow = c(1, 2))
plot(prochloraz_swath_spectrum[[1]], prochloraz_dda_spectrum[[1]],
     tolerance = 50e-6, main = "against DDA")
plot(prochloraz_swath_spectrum[[1]], prochloraz[[2]],
     tolerance = 50e-6, main = "against Metlin")
```

The spectra fit relatively well. Interestingly, the peak representing the
precursor (the right-most peak) seems to have a slightly shifted m/z value in
the reconstructed spectrum.

Similar to the DDA data, the reconstructed MS2 spectra from SWATH data could be
used in the annotation of the MS1 chromatographic peaks.

<!-- Other compounds with some issues to check: -->
<!-- - 306.162857, Buprofezin, Metlin 68681, consensus matches OKish with -->
<!--   SWATH. Metlin matches the DDA nicely, but not the SWATH. -->
<!-- - 300.0301, Azaconazole, Metlin 72479. Intensities match nicely, but m/z are -->
<!--   shifted. Metlin 20V matches DDA perfectly. SWATH m/z shifted. -->
<!-- - 224.083201. Spectra match relatively well, some almost perfect matches, but -->
<!--   consensus does not match that nicely. Nothing on Metlin. -->
<!-- - 256.1095, Dimethachlor, Metlin 72494. Intensities OK, m/z shifted. Metlin 20V -->
<!--   matches DDA perfectly. SWATH m/z shifted. -->


# Outlook

Currently, spectra data representation, handling and processing is being
re-implemented as part of the
[RforMassSpectrometry](https://rformassspectrometry.org) initiative aiming at
increasing the performance of methods and simplifying their use. Thus, parts of
the workflow described here will be changed (improved) in future.

Along with these developments, improved matching strategies for larger data sets
will be implemented as well as functionality to compare `Spectra` directly to
reference MS2 spectra from public annotation resources (e.g. Massbank or HMDB).

Regarding SWATH data analysis, future development will involve improved
selection of the correct MS2 chromatographic peaks considering also correlation
with intensity values across several samples.

# Session information

```{r sessionInfo}
sessionInfo()
```

# References